<?php
/**
 * All Purpose Theme Customizer
 *
 * @package All Purpose
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function all_purpose_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	
	$wp_customize->add_section( 'default_post_image' , array(
		'title'      => __('Default Post Image','all-purpose'),
		'priority'   => 30,
	) );	

	
    $wp_customize->add_setting(
        'no_post_img',
        array(
            'default'    => 'default',
            'capability' => 'edit_theme_options',
			'sanitize_callback' => 'all_purpose_sanitize_no_img',			
        )
    );

    $wp_customize->add_control(
        'no_post_img',
        array(
            'settings' => 'no_post_img',	
			'priority'    => 1,
            'label'    => __( 'Activate Default Image:', 'all-purpose' ),
            'section'  => 'default_post_image',
            'type'     => 'select',
            'choices'  => array(
                'hide' => __( 'Hide Default Post Image', 'all-purpose' ),
                'default' => __( 'Activate Default Post Image', 'all-purpose' ),
            ),
			'default'    => 'default'
        )
    );	
	
    $wp_customize->add_setting(
        'no_cube_animation',
        array(
            'default'    => 'default',
            'capability' => 'edit_theme_options',
			'sanitize_callback' => 'all_purpose_sanitize_no_animation',			
        )
    );

    $wp_customize->add_control(
        'no_cube_animation',
        array(
            'settings' => 'no_cube_animation',	
			'priority'    => 1,
            'label'    => __( 'Deactivate Cube Animation:', 'all-purpose' ),
            'section'  => 'default_post_image',
            'type'     => 'select',
            'choices'  => array(
                'hide' => __( 'Deactivate', 'all-purpose' ),
                'default' => __( 'Activate', 'all-purpose' ),
            ),
			'default'    => 'default'
        )
    );
	
}
add_action( 'customize_register', 'all_purpose_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function all_purpose_customize_preview_js() {
	wp_enqueue_script( 'all_purpose_customizer', get_template_directory_uri() . '/framework/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'all_purpose_customize_preview_js' );

function all_purpose_sanitize_no_img( $input ) {
	$valid = array(
        'hide' => __( 'Hide Default Post Image', 'all-purpose' ),
        'default' => __( 'Activate Default Post Image', 'all-purpose' ),
	);

	if ( array_key_exists( $input, $valid ) ) {
		return $input;
	} else {
		return '';
	}
}

function all_purpose_sanitize_no_animation( $input ) {
	$valid = array(
        'hide' => __( 'Deactivate', 'all-purpose' ),
        'default' => __( 'Activate', 'all-purpose' ),
	);

	if ( array_key_exists( $input, $valid ) ) {
		return $input;
	} else {
		return '';
	}
}

function all_purpose_cube_animation () { ?>
	
	<style>
		<?php if (get_theme_mod('no_cube_animation') == "hide") { ?>

		.app-basic:hover .app-transform-front {
			-webkit-transform: none !important;
			-moz-transform: none !important;
			-o-transform: none !important;
			-ms-transform: none !important;
			transform: none !important;
			opacity: 1 !important;
		}

		.app-basic:hover .app-transform-back {
			-webkit-transform: none !important;
			-moz-transform: none !important;
			-o-transform: none !important;
			-ms-transform: none !important;
			transform: none !important;
			opacity: 0 !important;
		}
		
		.app-basic:hover {
			opacity: 0.8;
			
		}
		<?php } ?>
	</style>
	
<?php } add_action('wp_head','all_purpose_cube_animation');